ChargeDataCopyWith<$R, $In extends ChargeData, $Out> class abstract

Available extensions

Constructors

ChargeDataCopyWith()

Properties

$asChargeData ChargeDataCopyWith<$R, ChargeData, $Out>

Available on ObjectCopyWith<$R, ChargeData, $Out>, provided by the ChargeDataValueCopy extension

no setter
authorization → AuthorizationDataCopyWith<$R, AuthorizationData, AuthorizationData>
no setter
customer → CustomerCopyWith<$R, Customer, Customer>
no setter
feesBreakdown → FeesBreakdownCopyWith<$R, FeesBreakdown, FeesBreakdown>?
no setter
hashCode int
The hash code for this object.
no setterinherited
plan PlanCopyWith<$R, Plan, Plan>?
no setter
planObject PlanCopyWith<$R, Plan, Plan>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splitDetail → SplitCopyWith<$R, Split, Split>?
no setter
subaccountDetail → SubaccountCopyWith<$R, Subaccount, Subaccount>?
no setter

Methods

$chain<$R2, $Out2>(Then<$Out2, $R2> t) ChargeDataCopyWith<$R2, $In, $Out2>
$delta(Map<String, dynamic> delta) → $R
inherited
$merge($In value) → $R
inherited
$update($Out transform($In)) → $R
inherited
call({DateTime? createdAt, String? channel, String? currency, int? id, String? domain, String? status, String? reference, int? amount, String? gatewayResponse, int? requestedAmount, DateTime? transactionDate, AuthorizationData? authorization, Customer? customer, String? message, DateTime? paidAt, String? ipAddress, String? metadata, dynamic log, int? fees, dynamic feesSplit, Plan? plan, Split? splitDetail, String? orderId, DateTime? paidAtAlt, DateTime? createdAtAlt, dynamic posTransactionData, dynamic source, FeesBreakdown? feesBreakdown, Plan? planObject, Subaccount? subaccountDetail}) → $R
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited