QrOptions class

Options specifically for QR code payment charges

This class encapsulates all parameters needed for QR code-based payments, where customers scan codes with their banking apps.

Constructors

QrOptions({required String email, required String amount, required Qr qr, String? reference, PaymentMetadata? metadata})
Creates options for QR code payment charges
const

Properties

amount String
Amount in smallest currency unit
final
email String
Customer's email address
final
hashCode int
The hash code for this object.
no setterinherited
metadata → PaymentMetadata?
Optional additional payment metadata
final
qr Qr
QR code provider configuration
final
reference String?
Optional unique transaction reference
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited