ipAddress property
IP address of the customer when the transaction was initiated.
Implementation
@MappableField(key: 'ip_address')
final String? ipAddress;
IP address of the customer when the transaction was initiated.
@MappableField(key: 'ip_address')
final String? ipAddress;