PaginationMeta class
Represents pagination metadata for plan list responses.
- Mixed-in types
- Annotations
-
- @MappableClass.new()
Constructors
Properties
-
copyWith
→ PaginationMetaCopyWith<
PaginationMeta, PaginationMeta, PaginationMeta> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → int
-
Current page number.
final
- pageCount → int
-
Total number of pages available.
final
- perPage → int
-
Number of plans per page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipped → int
-
Number of plans skipped (for pagination).
final
- total → int
-
Total number of plans available.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited